@@ -1,5 +1,5 @@
 
-/* Generated data (by glib-mkenums) */
+
 
 #ifndef __PANEL_APPLET_ENUMS_H__
 #define __PANEL_APPLET_ENUMS_H__
@@ -7,7 +7,9 @@
 G_BEGIN_DECLS
 
 
-/* --- ../libpanel-applet/panel-applet.h --- */
+/* --- ../../libpanel-applet/panel-applet.h --- */
+#define PANEL_TYPE_PANEL_APPLET_ORIENT panel_applet_orient_get_type()
+GType panel_applet_orient_get_type (void);
 #define PANEL_TYPE_PANEL_APPLET_BACKGROUND_TYPE panel_applet_background_type_get_type()
 GType panel_applet_background_type_get_type (void);
 #define PANEL_TYPE_PANEL_APPLET_FLAGS panel_applet_flags_get_type()
@@ -16,5 +18,5 @@ G_END_DECLS
 
 #endif /* __PANEL_APPLET_ENUMS_H__ */
 
-/* Generated data ends here */
+
 
